//@author: vvvv group
//@help: this is a very basic template. use it to start writing your own effects. if you want effects with lighting start from one of the GouraudXXXX or PhongXXXX effects
//@tags:
//@credits:

// --------------------------------------------------------------------------------------------------
// PARAMETERS:
// --------------------------------------------------------------------------------------------------

//transforms
float4x4 tW: WORLD;        //the models world matrix
float4x4 tV: VIEW;         //view matrix as set via Renderer (EX9)
float4x4 tP: PROJECTION;
float4x4 tWVP: WORLDVIEWPROJECTION;

//texture
texture TexR <string uiname="Texture Red";>;
sampler SampR = sampler_state    //sampler for doing the texture-lookup
{
	Texture   = (TexR);          //apply a texture to the sampler
	MipFilter = LINEAR;         //sampler states
	MinFilter = LINEAR;
	MagFilter = LINEAR;
};

texture TexG <string uiname="Texture Green";>;
sampler SampG = sampler_state    //sampler for doing the texture-lookup
{
	Texture   = (TexG);          //apply a texture to the sampler
	MipFilter = LINEAR;         //sampler states
	MinFilter = LINEAR;
	MagFilter = LINEAR;
};

texture TexB <string uiname="Texture Blue";>;
sampler SampB = sampler_state    //sampler for doing the texture-lookup
{
	Texture   = (TexB);          //apply a texture to the sampler
	MipFilter = LINEAR;         //sampler states
	MinFilter = LINEAR;
	MagFilter = LINEAR;
};

texture TexA <string uiname="Texture Alpha";>;
sampler SampA = sampler_state    //sampler for doing the texture-lookup
{
	Texture   = (TexA);          //apply a texture to the sampler
	MipFilter = LINEAR;         //sampler states
	MinFilter = LINEAR;
	MagFilter = LINEAR;
};


//texture transformation marked with semantic TEXTUREMATRIX to achieve symmetric transformations
float4x4 tTex: TEXTUREMATRIX <string uiname="Texture Transform";>;

//the data structure: "vertexshader to pixelshader"
//used as output data with the VS function
//and as input data with the PS function
struct vs2ps
{
	float4 Pos  : POSITION;
	float2 TexCd : TEXCOORD0;
	float2 TexCd1 : TEXCOORD1;
	float2 TexCd2 : TEXCOORD2;
	float2 TexCd3 : TEXCOORD3;
};

// --------------------------------------------------------------------------------------------------
// VERTEXSHADERS
// --------------------------------------------------------------------------------------------------
vs2ps VS(
float4 PosO  : POSITION,
float4 TexCd : TEXCOORD0,
float4 TexCd1 : TEXCOORD0,
float4 TexCd2 : TEXCOORD0,
float4 TexCd3 : TEXCOORD0)
{
	//declare output struct
	vs2ps Out;
	
	//transform position
	Out.Pos = mul(PosO, tWVP);
	
	//transform texturecoordinates
	Out.TexCd = mul(TexCd, tTex);
	Out.TexCd1 = mul(TexCd1, tTex);
	Out.TexCd2 = mul(TexCd2, tTex);
	Out.TexCd3 = mul(TexCd3, tTex);
	
	return Out;
}

// --------------------------------------------------------------------------------------------------
// PIXELSHADERS:
// --------------------------------------------------------------------------------------------------

float4 PS(vs2ps In): COLOR
{
	float4 colR = tex2D(SampR, In.TexCd);
	float4 colG = tex2D(SampG, In.TexCd1);
	float4 colB = tex2D(SampB, In.TexCd2);
	float4 colA = tex2D(SampA, In.TexCd3);
	float4 colRGBA = 0;
	colRGBA.r = colR;
	colRGBA.g = colG;
	colRGBA.b = colB;
	colRGBA.a = colA;	
	
	return colRGBA;
}

// --------------------------------------------------------------------------------------------------
// TECHNIQUES:
// --------------------------------------------------------------------------------------------------

technique TSimpleShader
{
	pass P0
	{
		//Wrap0 = U;  // useful when mesh is round like a sphere
		VertexShader = compile vs_1_1 VS();
		PixelShader  = compile ps_1_0 PS();
	}
}

technique TFixedFunction
{
	pass P0
	{
		//transforms
		WorldTransform[0]   = (tW);
		ViewTransform       = (tV);
		ProjectionTransform = (tP);
		
		//texturing
		Sampler[0] = (SampR);
		TextureTransform[0] = (tTex);
		TexCoordIndex[0] = 0;
		TextureTransformFlags[0] = COUNT2;
		//Wrap0 = U;  // useful when mesh is round like a sphere
		
		Lighting       = FALSE;
		
		//shaders
		VertexShader = NULL;
		PixelShader  = NULL;
	}
}
